Index: gp-templates/translations.php
===================================================================
--- gp-templates/translations.php	(revision 547)
+++ gp-templates/translations.php	(working copy)
@@ -19,10 +19,10 @@
 <form id="upper-filters-toolbar" class="filters-toolbar" action="" method="get" accept-charset="utf-8">
 	<div>
 	<?php if ( $can_approve ): ?>
-	<a href="#" class="revealing bulk"><?php _e('Bulk &darr;'); ?></a> <strong class="separator">&bull;</strong>
+	<a href="#" class="revealing bulk"><?php _e('Bulk &darr;'); ?></a> <span class="separator">&bull;</span>
 	<?php endif; ?>
 	<a href="#" class="revealing filter"><?php _e('Filter &darr;'); ?></a> <span class="separator">&bull;</span>
-	<a href="#" class="revealing sort"><?php _e('Sort &darr;'); ?></a> <strong class="separator">&bull;</strong>
+	<a href="#" class="revealing sort"><?php _e('Sort &darr;'); ?></a> <span class="separator">&bull;</span>
 	<?php
 	$filter_links = array();
 	$filter_links[] = gp_link_get( $url, __('All') );
@@ -173,10 +173,11 @@
 			$export_url = gp_url_project( $project, array( $locale->slug, $translation_set->slug, 'export-translations' ) );
 			$export_link = gp_link_get( $export_url , __('Export'), array('id' => 'export', 'filters' => add_query_arg( array( 'filters' => $filters ), $export_url ) ) );
 			$format_slugs = array_keys( GP::$formats );
-			$what_dropdown = gp_select( 'what-to-export', array('all' => _x('all current', 'export choice'), 'filtered' => _x('only matching the filter', 'export choice')), 'all' );
+			$what_dropdown = gp_select( 'what-to-export', array('all' => _x('all', 'export choice'), 'filtered' => _x('only matching the filter', 'export choice')), 'all' );
+			$status_dropdown = gp_select( 'filters[status]', array( 'current' => _x( 'translated strings', 'export choice' ), 'current_or_fuzzy_or_waiting' => _x( 'strings', 'export choice' ) ), 'current' );
 			$format_dropdown = gp_select( 'export-format', array_combine( $format_slugs, $format_slugs ), 'po' );
-			/* translators: 1: export 2: what to export dropdown (all/filtered) 3: export format */
-			$footer_links[] = sprintf( __('%1$s %2$s as %3$s'), $export_link, $what_dropdown, $format_dropdown );
+			/* translators: 1: export 2: what to export dropdown (all/filtered) 3: status (including/excluding non-approved translations) 4: export format */
+			$footer_links[] = sprintf( __('%1$s %2$s %3$s as %4$s'), $export_link, $what_dropdown, $status_dropdown, $format_dropdown );
 		}
 		
 		echo implode( ' &bull; ', apply_filters( 'translations_footer_links', $footer_links, $project, $locale, $translation_set ) );

